@@ -27,6 +27,7 @@ from neo4j.api import (
     Version,
     READ_ACCESS,
     WRITE_ACCESS,
+    DEFAULT_DATABASE,
 )
 from neo4j.io._courier import MessageInbox
 from neo4j.meta import get_user_agent
@@ -76,7 +77,7 @@ class Bolt3(Bolt):
     #: The pool of which this connection is a member
     pool = None
 
-    def __init__(self, unresolved_address, sock, max_connection_lifetime, *, auth=None, user_agent=None):
+    def __init__(self, unresolved_address, sock, max_connection_lifetime, *, auth=None, user_agent=None, routing_context=None):
         self.unresolved_address = unresolved_address
         self.socket = sock
         self.server_info = ServerInfo(Address(sock.getpeername()), Bolt3.PROTOCOL_VERSION)
@@ -90,6 +91,7 @@ class Bolt3(Bolt):
         self.supports_multiple_results = False
         self.supports_multiple_databases = False
         self._is_reset = True
+        self.routing_context = routing_context
 
         # Determine the user agent
         if user_agent:
@@ -141,7 +143,7 @@ class Bolt3(Bolt):
             logged_headers["credentials"] = "*******"
         log.debug("[#%04X]  C: HELLO %r", self.local_port, logged_headers)
         self._append(b"\x01", (headers,),
-                     response=InitResponse(self, on_success=self.server_info.metadata.update))
+                     response=InitResponse(self, on_success=self.server_info._update_metadata))
         self.send_all()
         self.fetch_all()
 
@@ -176,6 +178,17 @@ class Bolt3(Bolt):
             self._append(b"\x10", fields, Response(self, **handlers))
         self._is_reset = False
 
+    def run_get_routing_table(self, on_success, on_failure, database=DEFAULT_DATABASE):
+        if database != DEFAULT_DATABASE:
+            raise ConfigurationError("Database name parameter for selecting database is not supported in Bolt Protocol {!r}. Database name {!r}. Server Agent {!r}.".format(Bolt3.PROTOCOL_VERSION, database, self.server_info.agent))
+        self.run(
+            "CALL dbms.cluster.routing.getRoutingTable($context)",  # This is an internal procedure call. Only available if the Neo4j 3.5 is setup with clustering.
+            {"context": self.routing_context},
+            mode="r",                                               # Bolt Protocol Version(3, 0) supports mode="r"
+            on_success=on_success,
+            on_failure=on_failure,
+        )
+
     def discard(self, n=-1, qid=-1, **handlers):
         # Just ignore n and qid, it is not supported in the Bolt 3 Protocol.
         log.debug("[#%04X]  C: DISCARD_ALL", self.local_port)
